"""Switch executor module."""

from agent_flows.executors.switch.executor import SwitchExecutor
from agent_flows.executors.switch.models import SwitchExecutorConfig

__all__ = ["SwitchExecutor", "SwitchExecutorConfig"]
