"""Web Search executor module."""

from agent_flows.executors.web_search.executor import WebSearchExecutor
from agent_flows.executors.web_search.models import WebSearchExecutorConfig

__all__ = ["WebSearchExecutor", "WebSearchExecutorConfig"]
