"""Web Scraping executor module."""

from agent_flows.executors.web_scraping.executor import WebScrapingExecutor
from agent_flows.executors.web_scraping.models import WebScrapingExecutorConfig

__all__ = ["WebScrapingExecutor", "WebScrapingExecutorConfig"]
