"""Runtime resource management services."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from agent_flows.core.runtime.mcp_sessions import MCPSessionPool
    from agent_flows.core.runtime.variable_interpolator import VariableInterpolator


def __getattr__(name: str) -> type:
    """Lazy import for resource services."""
    if name == "VariableInterpolator":
        from agent_flows.core.runtime.variable_interpolator import VariableInterpolator

        return VariableInterpolator
    if name == "MCPSessionPool":
        from agent_flows.core.runtime.mcp_sessions import MCPSessionPool

        return MCPSessionPool
    raise AttributeError(f"module {__name__!r} has no attribute {name!r}")


__all__ = ["MCPSessionPool", "VariableInterpolator"]
